@@ -29,30 +29,6 @@ static ID id_pixdata;
 
 /****************************************************/
 /* The GdkPixbuf Structure */
-static VALUE
-get_colorspace(VALUE self)
-{
-    return GENUM2RVAL(gdk_pixbuf_get_colorspace(_SELF(self)), GDK_TYPE_COLORSPACE);
-}
-
-static VALUE
-get_n_channels(VALUE self)
-{
-    return INT2FIX(gdk_pixbuf_get_n_channels(_SELF(self)));
-}
-
-static VALUE
-get_has_alpha(VALUE self)
-{
-    return CBOOL2RVAL(gdk_pixbuf_get_has_alpha(_SELF(self)));
-}
-
-static VALUE
-get_bits_per_sample(VALUE self)
-{
-    return INT2FIX(gdk_pixbuf_get_bits_per_sample(_SELF(self)));
-}
-
 static int
 pixels_size(GdkPixbuf *pixbuf)
 {
@@ -75,7 +51,7 @@ get_pixels(VALUE self)
     int size;
 
     size = pixels_size(pixbuf);
-    return rb_str_new((const char*)gdk_pixbuf_get_pixels(pixbuf), size);
+    return rb_str_new((const char *)gdk_pixbuf_get_pixels(pixbuf), size);
 }
 
 static VALUE
@@ -87,7 +63,7 @@ set_pixels(VALUE self, VALUE pixels)
 
     size = pixels_size(pixbuf);
 
-    Check_Type(pixels, T_STRING);
+    StringValue(pixels);
     arg_size = RSTRING_LEN(pixels);
     if (arg_size != size)
       rb_raise(rb_eRangeError,
@@ -99,25 +75,7 @@ set_pixels(VALUE self, VALUE pixels)
     memcpy(gdk_pixbuf_get_pixels(pixbuf),
            RSTRING_PTR(pixels), MIN(RSTRING_LEN(pixels), size));
 
-  return pixels;
-}
-
-static VALUE
-get_width(VALUE self)
-{
-    return INT2FIX(gdk_pixbuf_get_width(_SELF(self)));
-}
-
-static VALUE
-get_height(VALUE self)
-{
-    return INT2FIX(gdk_pixbuf_get_height(_SELF(self)));
-}
-
-static VALUE
-get_rowstride(VALUE self)
-{
-    return INT2FIX(gdk_pixbuf_get_rowstride(_SELF(self)));
+    return pixels;
 }
 
 static VALUE
@@ -252,17 +210,15 @@ initialize(int argc, VALUE *argv, VALUE self)
                 buf = gdk_pixbuf_new_from_file(RVAL2CSTR(arg1), &error);
             }
         } else if (TYPE(arg1) == T_ARRAY) {
-            int i;
-            gchar** data = ALLOCA_N(gchar*, RARRAY_LEN(arg1));
-            for (i=0; i < RARRAY_LEN(arg1); i++) {
-		data[i] = RVAL2CSTR(RARRAY_PTR(arg1)[i]);
-            }
-            buf = gdk_pixbuf_new_from_xpm_data((const gchar**)data);
-            if (buf == NULL){
+            const gchar **data = RVAL2STRV(arg1);
+            buf = gdk_pixbuf_new_from_xpm_data(data);
+            if (buf == NULL) {
                 rb_gc();
-                buf = gdk_pixbuf_new_from_xpm_data((const gchar**)data);
-                if (buf == NULL) NOMEM_ERROR(&error);
+                buf = gdk_pixbuf_new_from_xpm_data(data);
             }
+            g_free(data);
+            if (buf == NULL)
+                NOMEM_ERROR(&error);
         } else {
             rb_raise(rb_eArgError, "Wrong type of 1st argument or wrong number of arguments");
         }
@@ -302,7 +258,7 @@ get_file_info(VALUE self, VALUE filename)
 #endif
 
 static VALUE
-save_to(VALUE self, gchar *filename, gchar *type, VALUE options)
+save_to(VALUE self, const gchar *filename, const gchar *type, VALUE options)
 {
     VALUE result = self;
     GError *error = NULL;
@@ -328,10 +284,10 @@ save_to(VALUE self, gchar *filename, gchar *type, VALUE options)
                 const_key = rb_id2name(SYM2ID(key));
                 keys[i] = (gchar *)const_key;
             } else {
-                keys[i] = RVAL2CSTR(key);
+                keys[i] = (gchar *)RVAL2CSTR(key);
             }
             value = rb_funcall(RARRAY_PTR(RARRAY_PTR(ary)[i])[1], to_s, 0);
-            values[i] = RVAL2CSTR(value);
+            values[i] = (gchar *)RVAL2CSTR(value);
         }
         keys[len] = NULL;
         values[len] = NULL;
@@ -625,15 +581,8 @@ Init_gdk_pixbuf2()
     /* 
      * The GdkPixbuf Structure 
      */
-    rb_define_method(gdkPixbuf, "colorspace", get_colorspace, 0);
-    rb_define_method(gdkPixbuf, "n_channels", get_n_channels, 0);
-    rb_define_method(gdkPixbuf, "has_alpha?", get_has_alpha, 0);
-    rb_define_method(gdkPixbuf, "bits_per_sample", get_bits_per_sample, 0);
-    rb_define_method(gdkPixbuf, "pixels", get_pixels, 0);
+    G_REPLACE_GET_PROPERTY(gdkPixbuf, "pixels", get_pixels, 0);
     rb_define_method(gdkPixbuf, "pixels=", set_pixels, 1);
-    rb_define_method(gdkPixbuf, "width", get_width, 0);
-    rb_define_method(gdkPixbuf, "height", get_height, 0);
-    rb_define_method(gdkPixbuf, "rowstride", get_rowstride, 0);
     rb_define_method(gdkPixbuf, "get_option", get_option, 1);
 
     /* GdkPixbufError */
