@@ -23,7 +23,7 @@ extern "C" {
 
 #define RBGLIB_MAJOR_VERSION 1
 #define RBGLIB_MINOR_VERSION 0
-#define RBGLIB_MICRO_VERSION 0
+#define RBGLIB_MICRO_VERSION 3
 
 #ifndef RSTRING_PTR
 #  define RSTRING_PTR(s) (RSTRING(s)->ptr)
@@ -52,13 +52,22 @@ typedef int GPid;
 #define CSTR2RVAL_LEN(s, l) (rbg_cstr2rval_len(s, l))
 #define CSTR2RVAL_ENC(s, e) (rbg_cstr2rval_with_encoding(s, e))
 #define CSTR2RVAL_LEN_ENC(s, l, e) (rbg_cstr2rval_len_with_encoding(s, l, e))
-#define CSTR2RVAL_FREE(s) (rbg_cstr2rval_with_free(s))
+#define CSTR2RVAL_FREE(s) (rbg_cstr2rval_free(s))
 #define CSTR2RVAL2(s) (CSTR2RVAL_FREE(s))
 
 #define RVAL2CSTRFILENAME(v) (rbg_filename_from_ruby(v))
+#define CSTRFILENAME2RVAL(s) (rbg_filename_to_ruby(s))
 #define CSTRFILENAME2RVAL_FREE(s) (rbg_filename_to_ruby_free(s))
 #define CSTRFILENAMEARRAY2RVAL_FREE(s) (rbg_filename_gslist_to_array_free(s))
 
+#define RVAL2STRV(ary) rbg_rval2strv(ary)
+#define RVAL2STRV_ACCEPT_NIL(ary) rbg_rval2strv_accept_nil(ary)
+#define RVAL2STRV_DUP(ary) rbg_rval2strv_dup(ary)
+#define RVAL2STRV_DUP_ACCEPT_NIL(ary) rbg_rval2strv_dup_accept_nil(ary)
+
+#define STRV2RVAL(strings) rbg_strv2rval(strings)
+#define STRV2RVAL_FREE(strings) rbg_strv2rval_free(strings)
+
 #define CBOOL2RVAL(b)   ((b) ? Qtrue : Qfalse)
 #define RVAL2CBOOL(b)   (RTEST(b))
 #define GERROR2RVAL(error) (rbgerr_gerror2exception(error))
@@ -83,20 +92,31 @@ RUBY_GLIB2_VAR VALUE mGLib;
 extern const gchar *rbg_rval_inspect(VALUE object);
 
 extern gchar* rbg_string_value_ptr(volatile VALUE* ptr); /* no longer used */
-extern gchar *rbg_rval2cstr(VALUE *str);
-extern gchar *rbg_rval2cstr_accept_nil(VALUE *str);
+extern const gchar *rbg_rval2cstr(VALUE *str);
+extern const gchar *rbg_rval2cstr_accept_nil(VALUE *str);
 extern VALUE rbg_cstr2rval(const gchar* str);
 extern VALUE rbg_cstr2rval_len(const gchar* str, gsize len);
 extern VALUE rbg_cstr2rval_with_encoding(const gchar* str,
                                          const gchar *encoding);
 extern VALUE rbg_cstr2rval_len_with_encoding(const gchar* str, gsize len,
                                              const gchar *encoding);
-extern VALUE rbg_cstr2rval_with_free(gchar* str);
+extern VALUE rbg_cstr2rval_free(gchar *str);
+/* just for backward compatibility. */
+extern VALUE rbg_cstr2rval_with_free(gchar *str);
 
+VALUE rbg_filename_to_ruby(const gchar *filename);
 extern VALUE rbg_filename_to_ruby_free(gchar *filename);
 extern gchar *rbg_filename_from_ruby(VALUE filename);
 extern VALUE rbg_filename_gslist_to_array_free(GSList *list);
 
+const gchar **rbg_rval2strv(VALUE ary);
+const gchar **rbg_rval2strv_accept_nil(VALUE ary);
+gchar **rbg_rval2strv_dup(VALUE ary);
+gchar **rbg_rval2strv_dup_accept_nil(VALUE ary);
+const gchar **rbg_rval2argv(VALUE ary);
+VALUE rbg_strv2rval(const gchar **strings);
+VALUE rbg_strv2rval_free(gchar **strings);
+
 /* rbgerror.h */
 extern VALUE rbgerr_gerror2exception(GError *error);
 extern VALUE rbgerr_define_gerror(GQuark domain, const gchar* name, VALUE module, VALUE parent, VALUE gtype);
