@@ -89,6 +89,8 @@ ioc_s_open(gint argc, VALUE *argv, VALUE self)
     if (TYPE(arg1) == T_FIXNUM){
 #ifdef G_OS_UNIX
         io = g_io_channel_unix_new(NUM2INT(arg1));
+#elif defined(G_OS_WIN32)
+        io = g_io_channel_win32_new_fd(NUM2INT(arg1));
 #else
         rb_raise(rb_eRuntimeError,
                  "GLib::IOChannel.new(fd) is supported on "
@@ -651,9 +653,12 @@ static VALUE
 ioc_win32_socket_initialize(VALUE self, VALUE socket)
 {
     GIOChannel *io = NULL;
+    int fd;
 
     rb_secure(4);
-    io = g_io_channel_win32_new_socket(NUM2INT(arg1));
+    /* TODO: support IO object */
+    fd = NUM2INT(socket);
+    io = g_io_channel_win32_new_socket(rb_w32_get_osfhandle(fd));
     G_INITIALIZE(self, io);
 
     return Qnil;
