@@ -70,7 +70,7 @@ keyfile_load_from_file(int argc, VALUE *argv, VALUE self)
     }
 
     ret = g_key_file_load_from_file(_SELF(self), 
-                                    (const gchar*)RVAL2CSTR(file),
+                                    RVAL2CSTR(file),
                                     gflags, &error);
 
     if (! ret) RAISE_GERROR(error);
@@ -137,39 +137,28 @@ keyfile_load_from_dirs(int argc, VALUE *argv, VALUE self)
     GError* error = NULL;
     gboolean success;
     const gchar *file;
-    gchar **search_dirs;
+    const gchar **search_dirs;
     gchar* full_path;
     GKeyFileFlags flags;
 
     rb_scan_args(argc, argv, "12", &rb_file, &rb_search_dirs, &rb_flags);
 
     file = RVAL2CSTR(rb_file);
-    if (NIL_P(rb_search_dirs)) {
-	search_dirs = NULL;
-    }
-    else {
-	long i, len;
-
-	Check_Type(rb_search_dirs, T_ARRAY);
-	len = RARRAY_LEN(rb_search_dirs);
-	search_dirs = ALLOCA_N(gchar *, len + 1);
-	for (i = 0; i < len; i++) {
-	    search_dirs[i] = RVAL2CSTR(RARRAY_PTR(rb_search_dirs)[i]);
-	}
-	search_dirs[i] = NULL;
-    }
+    search_dirs = RVAL2STRV_ACCEPT_NIL(rb_search_dirs);
     flags = G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS;
     if (!NIL_P(rb_flags))
         flags = RVAL2GFLAGS(rb_flags, G_TYPE_KEY_FILE_FLAGS);
 
-    if (search_dirs)
+    if (search_dirs != NULL)
 	success = g_key_file_load_from_dirs(_SELF(self), file,
-					    (const gchar **)search_dirs,
+					    search_dirs,
 					    &full_path, flags, &error);
     else
 	success = g_key_file_load_from_data_dirs(_SELF(self), file,
 						 &full_path, flags, &error);
 
+    g_free(search_dirs);
+
     if (!success)
 	RAISE_GERROR(error);
 
@@ -197,40 +186,21 @@ keyfile_get_start_group(VALUE self)
 static VALUE
 keyfile_get_groups(VALUE self)
 {
-    gsize length;
-    int i;
-    gchar** groups = g_key_file_get_groups(_SELF(self), &length);
-    VALUE ary = rb_ary_new();
-
-    for (i = 0; i < length; i++){
-        rb_ary_push(ary, CSTR2RVAL(groups[i]));
-    }
-
-    g_strfreev(groups);
-
-    return ary;
+    return STRV2RVAL_FREE(g_key_file_get_groups(_SELF(self), NULL));
 }
 
 static VALUE
 keyfile_get_keys(VALUE self, VALUE group_name)
 {
-    gsize length;
-    int i;
-    GError* error = NULL;
-    gchar** keys = g_key_file_get_keys(_SELF(self), 
-                                       (const gchar*)RVAL2CSTR(group_name),
-                                       &length, &error);
-    VALUE ary = rb_ary_new();
+    GError *error = NULL;
+    gchar **keys = g_key_file_get_keys(_SELF(self),
+                                       RVAL2CSTR(group_name),
+                                       NULL,
+                                       &error);
+    if (error != NULL)
+        RAISE_GERROR(error);
 
-    if (error) RAISE_GERROR(error);
-
-    for (i = 0; i < length; i++){
-        rb_ary_push(ary, CSTR2RVAL(keys[i]));
-    }
-
-    g_strfreev(keys);
-
-    return ary;
+    return STRV2RVAL_FREE(keys);
 }
 
 static VALUE
@@ -350,7 +320,7 @@ static VALUE
 keyfile_get_string_list(VALUE self, VALUE group_name, VALUE key)
 {
     VALUE ary;
-    gint i;
+    gsize i;
     gsize length;
     GError* error = NULL;
     gchar** ret = g_key_file_get_string_list(_SELF(self), 
@@ -375,7 +345,7 @@ keyfile_get_locale_string_list(int argc, VALUE *argv, VALUE self)
     VALUE group_name, key, locale;
     GError* error = NULL;
     VALUE ary;
-    gint i;
+    gsize i;
     gsize length;
     gchar** ret;
 
@@ -402,7 +372,7 @@ static VALUE
 keyfile_get_boolean_list(VALUE self, VALUE group_name, VALUE key)
 {
     VALUE ary;
-    gint i;
+    gsize i;
     gsize length;
     GError* error = NULL;
     gboolean* ret = g_key_file_get_boolean_list(_SELF(self), 
@@ -423,7 +393,7 @@ static VALUE
 keyfile_get_integer_list(VALUE self, VALUE group_name, VALUE key)
 {
     VALUE ary;
-    gint i;
+    gsize i;
     gsize length;
     GError* error = NULL;
     gint* ret = g_key_file_get_integer_list(_SELF(self), 
@@ -445,7 +415,7 @@ static VALUE
 keyfile_get_double_list(VALUE self, VALUE group_name, VALUE key)
 {
     VALUE ary;
-    gint i;
+    gsize i;
     gsize length;
     GError* error = NULL;
     gdouble* ret = g_key_file_get_double_list(_SELF(self), 
@@ -535,38 +505,36 @@ keyfile_set_double(VALUE self, VALUE group_name, VALUE key, VALUE value)
 #endif
 
 static VALUE
-keyfile_set_string_list(VALUE self, VALUE group_name, VALUE key, VALUE list)
+keyfile_set_string_list(VALUE self, VALUE group_name, VALUE key, VALUE rblist)
 {
-    gint len = RARRAY_LEN(list);
-    gchar** glist = ALLOCA_N(gchar*, len);
-    gint i;
-
-    for (i = 0; i < len; i++){
-        glist[i] = RVAL2CSTR(RARRAY_PTR(list)[i]);
-    }
+    VALUE ary = rb_ary_to_ary(rblist);
+    const gchar **list = RVAL2STRV(ary);
 
     g_key_file_set_string_list(_SELF(self), 
-                               (const gchar*)RVAL2CSTR(group_name),
-                               (const gchar*)RVAL2CSTR(key),
-                               (const gchar**)glist, len);
+                               RVAL2CSTR(group_name),
+                               RVAL2CSTR(key),
+                               list,
+                               RARRAY_LEN(ary));
+
+    g_free(list);
+
     return self;
 }
 
 static VALUE
-keyfile_set_locale_string_list(VALUE self, VALUE group_name, VALUE key, VALUE locale, VALUE list)
+keyfile_set_locale_string_list(VALUE self, VALUE group_name, VALUE key, VALUE locale, VALUE rblist)
 {
-    gint len = RARRAY_LEN(list);
-    gchar** glist = ALLOCA_N(gchar*, len);
-    gint i;
+    VALUE ary = rb_ary_to_ary(rblist);
+    const gchar **list = RVAL2STRV(ary);
 
-    for (i = 0; i < len; i++){
-        glist[i] = RVAL2CSTR(RARRAY_PTR(list)[i]);
-    }
+    g_key_file_set_locale_string_list(_SELF(self),
+                                      RVAL2CSTR(group_name),
+                                      RVAL2CSTR(key),
+                                      RVAL2CSTR(locale),
+                                      list,
+                                      RARRAY_LEN(ary));
 
-    g_key_file_set_locale_string_list(_SELF(self), (const gchar*)RVAL2CSTR(group_name),
-                                      (const gchar*)RVAL2CSTR(key),
-                                      (const gchar*)RVAL2CSTR(locale),
-                                      (const gchar**)glist, len);
+    g_free(list);
 
     return self;
 }
@@ -574,36 +542,44 @@ keyfile_set_locale_string_list(VALUE self, VALUE group_name, VALUE key, VALUE lo
 static VALUE
 keyfile_set_boolean_list(VALUE self, VALUE group_name, VALUE key, VALUE list)
 {
-    gint len = RARRAY_LEN(list);
-    gboolean* glist = ALLOCA_N(gboolean, len);
-    gint i;
+    VALUE ary;
+    long i, n;
+    gboolean *booleans;
 
-    for (i = 0; i < len; i++){
-        glist[i] = RVAL2CBOOL(RARRAY_PTR(list)[i]);
-    }
+    ary = rb_ary_to_ary(list);
+    n = RARRAY_LEN(ary);
+    booleans = ALLOCA_N(gboolean, n);
+    for (i = 0; i < n; i++)
+        booleans[i] = RVAL2CBOOL(RARRAY_PTR(ary)[i]);
 
     g_key_file_set_boolean_list(_SELF(self),
-                                (const gchar*)RVAL2CSTR(group_name),
-                                (const gchar*)RVAL2CSTR(key),
-                                glist, len);
+                                RVAL2CSTR(group_name),
+                                RVAL2CSTR(key),
+                                booleans,
+                                n);
+
     return self;
 }
 
 static VALUE
 keyfile_set_integer_list(VALUE self, VALUE group_name, VALUE key, VALUE list)
 {
-    gint len = RARRAY_LEN(list);
-    gint* glist = ALLOCA_N(gint, len);
-    gint i;
+    VALUE ary;
+    long i, n;
+    gint *ints;
 
-    for (i = 0; i < len; i++){
-        glist[i] = RVAL2CBOOL(RARRAY_PTR(list)[i]);
-    }
+    ary = rb_ary_to_ary(list);
+    n = RARRAY_LEN(ary);
+    ints = ALLOCA_N(gint, n);
+    for (i = 0; i < n; i++)
+        ints[i] = NUM2INT(RARRAY_PTR(ary)[i]);
 
     g_key_file_set_integer_list(_SELF(self),
-                                (const gchar*)RVAL2CSTR(group_name),
-                                (const gchar*)RVAL2CSTR(key),
-                                glist, len);
+                                RVAL2CSTR(group_name),
+                                RVAL2CSTR(key),
+                                ints,
+                                n);
+
     return self;
 }
 
@@ -611,18 +587,22 @@ keyfile_set_integer_list(VALUE self, VALUE group_name, VALUE key, VALUE list)
 static VALUE
 keyfile_set_double_list(VALUE self, VALUE group_name, VALUE key, VALUE list)
 {
-    gint len = RARRAY_LEN(list);
-    gdouble* glist = ALLOCA_N(gdouble, len);
-    gint i;
-
-    for (i = 0; i < len; i++){
-        glist[i] = RVAL2CBOOL(RARRAY_PTR(list)[i]);
-    }
+    VALUE ary;
+    long i, n;
+    gdouble *doubles;
+    
+    ary = rb_ary_to_ary(list);
+    n = RARRAY_LEN(ary);
+    doubles = ALLOCA_N(gdouble, n);
+    for (i = 0; i < n; i++)
+        doubles[i] = NUM2DBL(RARRAY_PTR(ary)[i]);
 
     g_key_file_set_double_list(_SELF(self),
-                                (const gchar*)RVAL2CSTR(group_name),
-                                (const gchar*)RVAL2CSTR(key),
-                               glist, len);
+                               RVAL2CSTR(group_name),
+                               RVAL2CSTR(key),
+                               doubles,
+                               n);
+
     return self;
 }
 #endif
@@ -631,11 +611,14 @@ static VALUE
 keyfile_set_comment(VALUE self, VALUE group_name, VALUE key, VALUE comment)
 {
     GError* error = NULL;
-    g_key_file_set_comment(_SELF(self), (const gchar*)RVAL2CSTR(group_name),
-                           (const gchar*)(NIL_P(key) ? NULL : RVAL2CSTR(key)),
-                           (const gchar*)RVAL2CSTR(comment), &error);
 
-    if (error) RAISE_GERROR(error);
+    g_key_file_set_comment(_SELF(self),
+                           RVAL2CSTR(group_name),
+                           RVAL2CSTR_ACCEPT_NIL(key),
+                           RVAL2CSTR(comment),
+                           &error);
+    if (error != NULL)
+        RAISE_GERROR(error);
 
     return self;
 }
@@ -644,9 +627,11 @@ static VALUE
 keyfile_remove_group(VALUE self, VALUE group_name)
 {
     GError* error = NULL;
-    g_key_file_remove_group(_SELF(self), (const gchar*)RVAL2CSTR(group_name), &error);
 
-    if (error) RAISE_GERROR(error);
+    g_key_file_remove_group(_SELF(self), RVAL2CSTR(group_name), &error);
+
+    if (error != NULL)
+        RAISE_GERROR(error);
 
     return self;
 }
@@ -655,12 +640,14 @@ static VALUE
 keyfile_remove_key(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
+
     g_key_file_remove_key(_SELF(self), 
-                          (const gchar*)RVAL2CSTR(group_name), 
-                          (const gchar*)RVAL2CSTR(key), 
+                          RVAL2CSTR(group_name), 
+                          RVAL2CSTR(key), 
                           &error);
 
-    if (error) RAISE_GERROR(error);
+    if (error != NULL)
+        RAISE_GERROR(error);
 
     return self;
 }
@@ -670,12 +657,14 @@ static VALUE
 keyfile_remove_comment(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
-    g_key_file_remove_comment(_SELF(self), 
-                          (const gchar*)RVAL2CSTR(group_name), 
-                          (const gchar*)RVAL2CSTR(key), 
-                          &error);
 
-    if (error) RAISE_GERROR(error);
+    g_key_file_remove_comment(_SELF(self), 
+                              RVAL2CSTR(group_name), 
+                              RVAL2CSTR(key), 
+                              &error);
+
+    if (error != NULL)
+        RAISE_GERROR(error);
 
     return self;
 }
