@@ -537,28 +537,60 @@ mc_prepare(VALUE self)
     return rb_assoc_new(CBOOL2RVAL(ret), INT2NUM(priority));
 }
 
+struct mc_query_body_args {
+    GPollFD *fds;
+    gint timeout_;
+    gint ret;
+};
+
+static VALUE
+mc_query_body(VALUE value)
+{
+    struct mc_query_body_args *args = (struct mc_query_body_args *)value;
+    gint i;
+    VALUE ary = rb_ary_new();
+
+    for (i = 0; i < args->ret; i++)
+        rb_ary_push(ary, BOXED2RVAL(&args->fds[i], G_TYPE_POLL_FD));
+    
+    return rb_assoc_new(INT2NUM(args->timeout_), ary);
+}
+
+static VALUE
+mc_query_ensure(VALUE value)
+{
+    g_free((GPollFD *)value);
+
+    return Qnil;
+}
+
 static VALUE
 mc_query(VALUE self, VALUE max_priority)
 {
-    gint i, timeout_;
-    VALUE ary;
+    gint timeout_;
+    struct mc_query_body_args args;
    
-    GPollFD* fds = g_new (GPollFD, 100);
-    gint ret = g_main_context_query(_SELF(self), NUM2INT(max_priority), 
-                               &timeout_, fds, 100);
+    GPollFD *fds = g_new(GPollFD, 100);
+    gint ret = g_main_context_query(_SELF(self),
+                                    NUM2INT(max_priority), 
+                                    &timeout_,
+                                    fds,
+                                    100);
     if (ret > 100) {
         g_free(fds);
         fds = g_new(GPollFD, ret);
-        g_main_context_query(_SELF(self), NUM2INT(max_priority),
-                             &timeout_, fds, ret);
+        g_main_context_query(_SELF(self),
+                             NUM2INT(max_priority),
+                             &timeout_,
+                             fds,
+                             ret);
     }
 
-    ary = rb_ary_new();
-    for (i = 0; i < ret; i++)
-        rb_ary_push(ary, BOXED2RVAL(&fds[i], G_TYPE_POLL_FD));
-    
-    g_free(fds);
-    return rb_assoc_new(INT2NUM(timeout_), ary);
+    args.fds = fds;
+    args.timeout_ = timeout_;
+    args.ret = ret;
+    return rb_ensure(mc_query_body, (VALUE)&args,
+                     mc_query_ensure, (VALUE)fds);
 }
 
 /* How can I implement this?
