@@ -79,8 +79,7 @@ gobj_s_signal_new(int argc, VALUE* argv, VALUE self)
     VALUE signal_name, signal_flags, accumulator, return_type, params;
     GClosure* class_closure;
     GType* param_types;
-    guint n_params;
-    int i;
+    long i, n_params;
     guint sig;
 
     rb_scan_args(argc, argv, "4*", &signal_name, &signal_flags,
@@ -287,7 +286,7 @@ gobj_sig_get_invocation_hint(VALUE self)
 }
 #endif
 
-struct emit_arg{
+struct emit_arg {
     VALUE self;
     VALUE args;
 
@@ -307,7 +306,7 @@ emit_body(struct emit_arg* arg)
     g_value_unset(&param);
 
     {
-        int i;
+        guint i;
         for (i = 0; i < arg->query.n_params; i++){
             GType gtype = arg->query.param_types[i] & ~G_SIGNAL_TYPE_STATIC_SCOPE;
 
@@ -370,7 +369,7 @@ gobj_sig_emit(int argc, VALUE *argv, VALUE self)
 
     g_signal_query(signal_id, &arg.query);
 
-    if (arg.query.n_params != RARRAY_LEN(arg.args))
+    if (arg.query.n_params != (guint)RARRAY_LEN(arg.args))
         rb_raise(rb_eArgError, "wrong number of arguments(%ld for %d)",
                  RARRAY_LEN(arg.args) + 1,
                  arg.query.n_params + 1);
@@ -484,7 +483,7 @@ chain_from_overridden_body(struct emit_arg* arg)
 
     {
         GValue* params = arg->instance_and_params->values + 1;
-        int i;
+        guint i;
         for (i = 0; i < arg->query.n_params; i++) {
             GType gtype = arg->query.param_types[i] & ~G_SIGNAL_TYPE_STATIC_SCOPE;
             g_value_init(params + i, gtype);
@@ -526,7 +525,7 @@ gobj_sig_chain_from_overridden(int argc, VALUE *argv, VALUE self)
         g_signal_query(hint->signal_id, &arg.query);
     }
 
-    if (arg.query.n_params != argc)
+    if (arg.query.n_params != (guint)argc)
         rb_raise(rb_eArgError, "wrong number of arguments(%d for %d)",
                  argc, arg.query.n_params);
 
@@ -687,7 +686,7 @@ query_param_types(VALUE self)
 {
     GSignalQuery* query;
     VALUE result;
-    int i;
+    guint i;
     Data_Get_Struct(self, GSignalQuery, query);
 
     result = rb_ary_new2(query->n_params);
@@ -866,7 +865,7 @@ rbgobj_define_action_methods(VALUE klass)
     GString* source;
     guint n_ids;
     guint* ids;
-    int i;
+    guint i;
 
     if (gtype == G_TYPE_INTERFACE)
         return;
@@ -884,7 +883,7 @@ rbgobj_define_action_methods(VALUE klass)
             gchar* method_name = g_strdup(query.signal_name);
             gchar* p;
             GString* args;
-            int j;
+            guint j;
 
             for (p = method_name; *p; p++)
                 if (*p == '-')
