@@ -594,16 +594,12 @@ gdkwin_set_back_pixmap(VALUE self, VALUE pixmap, VALUE parent_relative)
     return self;
 }
 
-#if !GTK_CHECK_VERSION(2, 18, 0)
-static VALUE
-gdkwin_set_cursor(VALUE self, VALUE cursor)
-{
-    gdk_window_set_cursor(_SELF(self), 
-                          (GdkCursor*)(NIL_P(cursor) ? NULL : RVAL2BOXED(cursor, GDK_TYPE_CURSOR)));
-
-    return self;
-}
-#endif
+/* Properties:
+ *
+ * void                gdk_window_set_cursor               (GdkWindow *window,
+ *                                                          GdkCursor *cursor);
+ * GdkCursor *         gdk_window_get_cursor               (GdkWindow *window);
+ */
 
 /* Obsolete
    #define     gdk_window_set_colormap
@@ -896,7 +892,6 @@ gdkwin_s_get_default_root_window(VALUE self)
 GdkPointerHooks* gdk_set_pointer_hooks      (const GdkPointerHooks *new_hooks);
 */
 
-
 /* From X Window System Interaction */
 static VALUE
 gdkwin_foreign_new(int argc, VALUE *argv, VALUE self)
@@ -909,11 +904,12 @@ gdkwin_foreign_new(int argc, VALUE *argv, VALUE self)
     switch(argc)
     {
       case 1:
-    	win = gdk_window_foreign_new(NUM2UINT(arg[0]));
+    	win = gdk_window_foreign_new(RVAL2GDKNATIVEWINDOW(arg[0]));
 	break;
       case 2:
 #if GTK_CHECK_VERSION(2,2,0)
-    	win = gdk_window_foreign_new_for_display(RVAL2GOBJ(arg[0]), NUM2UINT(arg[1])); 
+    	win = gdk_window_foreign_new_for_display(RVAL2GOBJ(arg[0]),
+                                                 RVAL2GDKNATIVEWINDOW(arg[1])); 
 #else
     	win = gdk_window_foreign_new(NUM2UINT(arg[1])); 
         rb_warn("Not supported in GTK+-2.0.x.");
@@ -938,11 +934,11 @@ gdkwin_lookup(int argc, VALUE *argv, VALUE self)
     switch(argc)
     {
       case 1:
-    	win = gdk_window_lookup(NUM2UINT(arg[0]));
+    	win = gdk_window_lookup(RVAL2GDKNATIVEWINDOW(arg[0]));
 	break;
       case 2:
 #if GTK_CHECK_VERSION(2,2,0)
-    	win = gdk_window_lookup_for_display(RVAL2GOBJ(arg[0]), NUM2UINT(arg[1])); 
+    	win = gdk_window_lookup_for_display(RVAL2GOBJ(arg[0]), RVAL2GDKNATIVEWINDOW(arg[1])); 
 #else
     	win = gdk_window_lookup(NUM2UINT(arg[1])); 
         rb_warn("Not supported in GTK+-2.0.x.");
@@ -1073,9 +1069,6 @@ Init_gtk_gdk_window()
     rb_define_method(gdkWindow, "set_title", gdkwin_set_title, 1);
     rb_define_method(gdkWindow, "set_background", gdkwin_set_background, 1);
     rb_define_method(gdkWindow, "set_back_pixmap", gdkwin_set_back_pixmap, 2);
-#if !GTK_CHECK_VERSION(2, 18, 0)
-    rb_define_method(gdkWindow, "set_cursor", gdkwin_set_cursor, 1);
-#endif
     rb_define_method(gdkWindow, "user_data", gdkwin_get_user_data, 0);
     rb_define_method(gdkWindow, "geometry", gdkwin_get_geometry, 0);
     rb_define_method(gdkWindow, "set_geometry_hints", gdkwin_set_geometry_hints, 2);
