@@ -21,19 +21,12 @@ hb_initialize(VALUE self)
     return Qnil;
 }
 
-static VALUE
-hb_child_detached(VALUE self)
-{
-    return CBOOL2RVAL(GTK_HANDLE_BOX(RVAL2GOBJ(self))->child_detached);
-}
-
 void 
 Init_gtk_handle_box()
 {
     VALUE gHandleBox = G_DEF_CLASS(GTK_TYPE_HANDLE_BOX, "HandleBox", mGtk);
 
     rb_define_method(gHandleBox, "initialize", hb_initialize, 0);
-    rb_define_method(gHandleBox, "child_detached?", hb_child_detached, 0);
     rb_undef_method(gHandleBox, "shadow");
     rb_undef_method(gHandleBox, "shadow=");
     rb_undef_method(gHandleBox, "set_shadow");
