@@ -49,17 +49,15 @@ txt_get_char_count(VALUE self)
     return INT2NUM(gtk_text_buffer_get_char_count(_SELF(self)));
 }
 
-static VALUE
-txt_get_tag_table(VALUE self)
-{
-    return GOBJ2RVAL(gtk_text_buffer_get_tag_table(_SELF(self)));
-}
+/* Defined as Properties:
+GtkTextTagTable *   gtk_text_buffer_get_tag_table       (GtkTextBuffer *buffer);
+*/
 
 static VALUE
 txt_set_text(VALUE self, VALUE text)
 {
     StringValue(text);
-    gtk_text_buffer_set_text(_SELF(self), RVAL2CSTR(text), RSTRING_LEN(text));
+    gtk_text_buffer_set_text(_SELF(self), RSTRING_PTR(text), RSTRING_LEN(text));
     return self;
 }
 
@@ -77,17 +75,18 @@ static VALUE
 txt_insert_at_cursor(VALUE self, VALUE text)
 {
     StringValue(text);
-    gtk_text_buffer_insert_at_cursor(_SELF(self),
-                                     RVAL2CSTR(text), RSTRING_LEN(text));
+    gtk_text_buffer_insert_at_cursor(_SELF(self), RSTRING_PTR(text), RSTRING_LEN(text));
     return self;
 }
 
 static VALUE
 txt_insert_interactive(VALUE self, VALUE iter, VALUE text, VALUE editable)
 {
+    StringValue(text);
+
     return CBOOL2RVAL(gtk_text_buffer_insert_interactive(_SELF(self),
                                                          RVAL2ITR(iter),
-                                                         RVAL2CSTR(text),
+                                                         RSTRING_PTR(text),
                                                          RSTRING_LEN(text),
                                                          RVAL2CBOOL(editable)));
 }
@@ -95,8 +94,10 @@ txt_insert_interactive(VALUE self, VALUE iter, VALUE text, VALUE editable)
 static VALUE
 txt_insert_interactive_at_cursor(VALUE self, VALUE text, VALUE editable)
 {
+    StringValue(text);
+
     return CBOOL2RVAL(gtk_text_buffer_insert_interactive_at_cursor(_SELF(self),
-                                                                   RVAL2CSTR(text),
+                                                                   RSTRING_PTR(text),
                                                                    RSTRING_LEN(text),
                                                                    RVAL2CBOOL(editable)));
 }
@@ -346,6 +347,7 @@ txt_deserialize(VALUE self, VALUE content_buffer, VALUE format, VALUE iter, VALU
     GError* error = NULL;
     gboolean ret;
 
+    /* TODO: Why not StringValue(data)? */
     Check_Type(data, T_STRING);
     ret = gtk_text_buffer_deserialize(_SELF(self), _SELF(content_buffer),
                                       RVAL2ATOM(format),
@@ -493,6 +495,7 @@ serialize_func(GtkTextBuffer *register_buffer, GtkTextBuffer *content_buffer, Gt
 
     /* This should return data as String */
     result = G_PROTECT_CALLBACK(invoke_callback, &arg);
+    /* TODO: Why not StringValue(result)? */
     Check_Type(result, T_STRING);
     *length = RSTRING_LEN(result);
     return (guint8*)(NIL_P(rb_errinfo()) ? RSTRING_PTR(result) : NULL);
@@ -676,7 +679,7 @@ txt_insert(int argc, VALUE *argv, VALUE self)
         start_offset = gtk_text_iter_get_offset(RVAL2ITR(where));
         StringValue(value);
         gtk_text_buffer_insert(_SELF(self), RVAL2ITR(where),
-                               RVAL2CSTR(value), RSTRING_LEN(value));
+                               RSTRING_PTR(value), RSTRING_LEN(value));
         
         if (RARRAY_LEN(tags) == 0)
             return self;
@@ -808,9 +811,8 @@ Init_gtk_textbuffer()
     rb_define_method(gTextBuffer, "initialize", txt_initialize, -1);
     rb_define_method(gTextBuffer, "line_count", txt_get_line_count, 0);
     rb_define_method(gTextBuffer, "char_count", txt_get_char_count, 0);
-    rb_define_method(gTextBuffer, "tag_table", txt_get_tag_table, 0);
 
-    rb_define_method(gTextBuffer, "set_text", txt_set_text, 1);
+    G_REPLACE_SET_PROPERTY(gTextBuffer, "text", txt_set_text, 1);
     rb_define_method(gTextBuffer, "insert", txt_insert, -1);
     rb_define_method(gTextBuffer, "insert_with_tags", txt_insert_with_tags, -1);
 #if GTK_CHECK_VERSION(2,6,0)
@@ -826,7 +828,7 @@ Init_gtk_textbuffer()
     rb_define_method(gTextBuffer, "delete_interactive", txt_delete_interactive, 3);
 
     rb_define_method(gTextBuffer, "get_text", txt_get_text, -1);
-    rb_define_method(gTextBuffer, "text", txt_get_text_all, 0);
+    G_REPLACE_GET_PROPERTY(gTextBuffer, "text", txt_get_text_all, 0);
     rb_define_method(gTextBuffer, "get_slice", txt_get_slice, -1);
     rb_define_method(gTextBuffer, "slice", txt_get_slice_all, 0);
 
@@ -852,6 +854,7 @@ Init_gtk_textbuffer()
 #endif
     rb_define_method(gTextBuffer, "modified?", txt_get_modified, 0);
     rb_define_method(gTextBuffer, "set_modified", txt_set_modified, 1);
+    G_DEF_SETTER(gTextBuffer, "modified");
 
     rb_define_method(gTextBuffer, "add_selection_clipboard", txt_add_selection_clipboard, 1);
     rb_define_method(gTextBuffer, "remove_selection_clipboard", txt_remove_selection_clipboard, 1);
@@ -894,7 +897,5 @@ Init_gtk_textbuffer()
     rb_define_method(gTextBuffer, "apply_tag", txt_apply_tag, 3);
     rb_define_method(gTextBuffer, "remove_tag", txt_remove_tag, 3);
     rb_define_method(gTextBuffer, "remove_all_tags", txt_remove_all_tags, 2);
-
-    G_DEF_SETTERS(gTextBuffer);
 }
 
